@@ -11,10 +11,10 @@ binomTest <- function(y1, y2, n1=sum(y1), n2=sum(y2), p=n1/(n1+n2))
 #	Gordon Smyth
 #	In statmod package 15 Nov 2003.
 #	In edgeR package 11 Feb 2011.
-#	Last modified 9 Jun 2020.
+#	Last modified 13 Jul 2024.
 {
 	if(length(y1) != length(y2)) stop("y1 and y2 must have same length")
-	if(any(is.na(y1)) || any(is.na(y2))) stop("missing values not allowed")
+	if(anyNA(y1) || anyNA(y2)) stop("missing values not allowed")
 	y1 <- round(y1)
 	y2 <- round(y2)
 	if(any(y1<0) || any(y2<0)) stop("y1 and y2 must be non-negative")
